"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Provider = void 0;
var _react = _interopRequireDefault(require("react"));
var _ChatComponent = require("./ChatComponent");
var _constants = require("./constants");
var _entities = require("./entities");
var _gateways = require("./gateways");
var _adapters = require("./infra/adapters");
var _utils = require("./utils");
var _global = require("./global");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const Provider = props => {
  _global.Global.botId = props.botId;
  _global.Global.params = props.params;
  const env = (0, _utils.getEnvironment)({
    staging: props.staging,
    dev: props.dev
  });
  const configurations = new _entities.ChatConfigurations(_constants.initialConfigs.title, _constants.initialConfigs.poweredBy, _constants.initialConfigs.poweredByUrl, {});
  const logger = new _adapters.ConsoleLoggerAdapter();
  const wsAdapter = new _adapters.WebSocketAdapter(env.SOCKET_URL, logger);
  const httpClient = new _adapters.AxiosHttpConnectionAdapter(env.API_URL, logger);
  const storage = new _adapters.EncryptedStorageAdapter();
  const session = new _gateways.SessionStorageGateway(storage, httpClient, wsAdapter);
  const messageGateway = new _gateways.MessageHttpSocketGateway(wsAdapter, httpClient, storage, session);
  const getBotHttpClient = new _adapters.AxiosHttpConnectionAdapter(env.GET_BOT_URL, logger);
  const chatConfigurationsGateway = new _gateways.ChatConfigurationsHttpGateway(getBotHttpClient);
  const notificationAdapter = new _adapters.NotificationAdapter();
  const notificationsGateway = new _gateways.NotificationRnGateway(notificationAdapter);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_ChatComponent.ChatComponent, {
    sessionGateway: session,
    messagesGateway: messageGateway,
    configurations: configurations,
    configurationsGateway: chatConfigurationsGateway,
    notifications: notificationsGateway,
    ws: wsAdapter,
    appearance: props.appearance
  }));
};
exports.Provider = Provider;
//# sourceMappingURL=Provider.js.map